# arxivAssistant
A small package to access the daily astronomy articles from arXiv.org from the console.
Install it with pip:

```pip install arxivAssistant```

Once installed, you can use it from the command line:

```arxiv-today```
